<h1 align="center">Professor Estimium</h1>

<p align="center">
    <img src="./docs/images/professor-estimium.png" alt="Professor Estimium" class="center">
</p>

<h2 align="center">A collection of ML tools written with professor's chalk</h2>

<p align="center">
    <a href="https://github.com/psf/black"><img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Code style: black"></a>
    <a href="https://github.com/pre-commit/pre-commit"><img src="https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white" alt="pre-commit" style="max-width:100%;"></a>
</p>

<!-- prettier-ignore -->
> _Application of these estimators is left as an exercise for the reader_ - Professor Estimium

**Professor Estimium** is a **Python** package implementing frequently used
functionalities to reduce writing Machine Learning boilerplates to a minimum.

The professor was guided by the principle that:

<!-- prettier-ignore -->
> _If you did something once, you did it enough times._
